@@ -3,7 +3,7 @@ package ASP4;
 
 use strict;
 use warnings 'all';
-our $VERSION = '1.033';
+our $VERSION = '1.034';
 
 
 1;# return true:
@@ -261,6 +261,17 @@ The output would be:
     </body>
   </html>
 
+=head1 BUGS
+
+It's possible that some bugs have found their way into this release.
+
+Use RT L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=ASP4> to submit bug reports.
+
+=head1 HOMEPAGE
+
+Please visit the ASP4 homepage at L<http://0x31337.org/code/> to see examples
+of ASP4 in action.
+
 =head1 AUTHOR
 
 John Drago <jdrago_999@yahoo.com>
